@@ -343,6 +343,7 @@ def describe_jump(n: Element) -> str:
 def replace_commented_xml_with_empty_lines(xml_string: str) -> str:
     # Define a regular expression pattern to match XML comments
     comment_pattern = "<!--(.*?)-->"
+    cdata_pattern = "<!\[CDATA\[(.*?)\]\]>"
 
     # Use re.sub to replace the matched comments with an equivalent number of empty lines
     def replace(match: re.Match[str]) -> str:
@@ -351,6 +352,7 @@ def replace_commented_xml_with_empty_lines(xml_string: str) -> str:
         return empty_lines
 
     result = re.sub(comment_pattern, replace, xml_string, flags=re.DOTALL)
+    result = re.sub(cdata_pattern, replace, result, flags=re.DOTALL)
     return result
 
 
